----
BUG: The temporal adjustment node does not get the full r.* targetlist
----





A=# explain analyze verbose select a from (r align s on r.b=s.d with (ts,te,ts,te)) x;
WARNING:  could not dump unrecognized node type: 738
                                                                     QUERY PLAN                                                       
               
--------------------------------------------------------------------------------------------------------------------------------------
---------------
 Subquery Scan on x  (cost=620.67..754.12 rows=4710 width=8) (actual time=0.076..0.099 rows=10 loops=1)
   Output: x.a
   ->  Temporal Adjustment  (cost=620.67..707.02 rows=4710 width=32) (actual time=0.075..0.097 rows=10 loops=1)
         Output: r.a, (NULL::character(1)), (NULL::integer), (NULL::integer), r."*RN*", (GREATEST(r.ts, s.ts)), (LEAST(r.te, s.te))
         ->  Sort  (cost=620.67..624.60 rows=1570 width=32) (actual time=0.072..0.072 rows=6 loops=1)
               Output: r.a, (NULL::character(1)), (NULL::integer), (NULL::integer), r."*RN*", (GREATEST(r.ts, s.ts)), (LEAST(r.te, s.te))
               Sort Key: r."*RN*", (GREATEST(r.ts, s.ts)), (LEAST(r.te, s.te))
               Sort Method: quicksort  Memory: 25kB
               ->  Merge Left Join  (cost=262.58..537.33 rows=1570 width=32) (actual time=0.051..0.054 rows=6 loops=1)
                     Output: r.a, NULL::character(1), NULL::integer, NULL::integer, r."*RN*", GREATEST(r.ts, s.ts), LEAST(r.te, s.te)
                     Merge Cond: (r.b = s.d)
                     Join Filter: ((r.ts < s.te) AND (r.te > s.ts))
                     Rows Removed by Join Filter: 1
                     ->  Sort  (cost=144.36..148.29 rows=1570 width=32) (actual time=0.024..0.024 rows=3 loops=1)
                           Output: r.a, r."*RN*", r.ts, r.te, r.b
                           Sort Key: r.b
                           Sort Method: quicksort  Memory: 25kB
                           ->  Subquery Scan on r  (cost=0.00..61.03 rows=1570 width=32) (actual time=0.014..0.018 rows=3 loops=1)
                                 Output: r.a, r."*RN*", r.ts, r.te, r.b
                                 ->  WindowAgg  (cost=0.00..45.33 rows=1570 width=24) (actual time=0.008..0.011 rows=3 loops=1)
                                       Output: r_1.a, r_1.b, r_1.ts, r_1.te, row_number() OVER (?)
                                       ->  Seq Scan on public.r r_1  (cost=0.00..25.70 rows=1570 width=24) (actual time=0.005..0.006 rows=3 loops=1)
                                             Output: r_1.a, r_1.b, r_1.ts, r_1.te
                     ->  Sort  (cost=118.22..122.47 rows=1700 width=16) (actual time=0.023..0.023 rows=5 loops=1)
                           Output: s.ts, s.te, s.d
                           Sort Key: s.d
                           Sort Method: quicksort  Memory: 25kB
                           ->  Seq Scan on public.s  (cost=0.00..27.00 rows=1700 width=16) (actual time=0.001..0.002 rows=3 loops=1)
                                 Output: s.ts, s.te, s.d
 Planning time: 0.159 ms
 Execution time: 0.145 ms
(31 rows)


